/*
	setled - set/unset keyboard leds
	Copyright (C) 2006  Avelino Herrera Morales

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdio.h>
#include <sys/stat.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <sys/kd.h>
#include <fcntl.h>

int main(int argc, char *argv[]) {
	int i, fd;
	long int data;

	if (argc < 2) {
		printf("syntax: %s [n|c|s][-|+] ...\n", argv[0]);
		printf("n = num lock\n");
		printf("c = caps lock\n");
		printf("s = scroll lock\n");
		printf("Examples:\n");
		printf("\t%s c+ n-     ---> switchs on caps lock led and switchs off num lock led\n", argv[0]);
		printf("\t%s s- n- c-  ---> switchs off all leds\n", argv[0]);
		return 1;
	}

	/* abrimos la consola */
	fd = open("/dev/console", O_NOCTTY);
	if (fd < 0) {
		perror("open");
		return 1;
	}
	/* obtenemos el valor actual de los leds del teclado */
	if (ioctl(fd, KDGETLED, &data) < 0) {
		perror("ioctl");
		return 1;
	}
	data &= 0x0F;
	/* para activar un led individual:
	data |= LED_NUM;
	if (ioctl(fd, KDSETLED, data) < 0) {
		perror("ioctl");
		return 1;
	}
	*/
	for (i = 0; i < argc; i++) {
		if (argv[i][0] == 'n') {
			if (argv[i][1] == '-')
				data &= ~LED_NUM;
			else
				data |= LED_NUM;
		}
		else if (argv[i][0] == 'c') {
			if (argv[i][1] == '-')
				data &= ~LED_CAP;
			else
				data |= LED_CAP;
		}
		else if (argv[i][0] == 's') {
			if (argv[i][1] == '-')
				data &= ~LED_SCR;
			else
				data |= LED_SCR;
		}
	}
	if (ioctl(fd, KDSETLED, data) < 0) {
		perror("ioctl");
		return 1;
	}
	return 0;
}
